@@ -39,7 +39,7 @@ import java.util.List;
 import javax.security.auth.x500.X500Principal;
 
 import org.bouncycastle.asn1.ASN1ObjectIdentifier;
-import org.bouncycastle.asn1.x509.X509Extension;
+import org.bouncycastle.asn1.x509.Extension;
 import org.bouncycastle.cert.X509CertificateHolder;
 import org.bouncycastle.cert.jcajce.JcaX509CertificateHolder;
 import org.bouncycastle.operator.ContentVerifierProvider;
@@ -62,7 +62,7 @@ import eu.emi.security.authn.x509.proxy.ProxyUtils;
 
 /**
  * The Default VOMS validation strategy.
- * 
+ *
  * @author andreaceccanti
  *
  */
@@ -239,8 +239,9 @@ public class DefaultVOMSValidationStrategy implements VOMSACValidationStrategy {
   private boolean checkNoRevAvailExtension(VOMSAttribute attributes,
     List<VOMSValidationErrorMessage> validationErrors) {
 
-    X509Extension noRevAvail = attributes.getVOMSAC().getExtension(
-      X509Extension.noRevAvail);
+    Extension noRevAvail = attributes.getVOMSAC().getExtension(
+      Extension.noRevAvail);
+
     if (noRevAvail != null && noRevAvail.isCritical()) {
       validationErrors.add(newErrorMessage(other,
         "NoRevAvail AC extension cannot be critical!"));
@@ -252,8 +253,9 @@ public class DefaultVOMSValidationStrategy implements VOMSACValidationStrategy {
   private boolean checkAuthorityKeyIdentifierExtension(
     VOMSAttribute attributes, List<VOMSValidationErrorMessage> validationErrors) {
 
-    X509Extension authKeyId = attributes.getVOMSAC().getExtension(
-      X509Extension.authorityKeyIdentifier);
+    Extension authKeyId = attributes.getVOMSAC().getExtension(
+      Extension.authorityKeyIdentifier);
+
     if (authKeyId != null && authKeyId.isCritical()) {
       validationErrors.add(newErrorMessage(other,
         "AuthorityKeyIdentifier AC extension cannot be critical!"));
@@ -376,5 +378,4 @@ public class DefaultVOMSValidationStrategy implements VOMSACValidationStrategy {
       throw new VOMSError("Error verifying AC signature: " + e.getMessage(), e);
     }
   }
-
 }
