@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2012.
+ * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,12 +32,11 @@ import java.util.Arrays;
  */
 public class DefaultVOMSESLookupStrategy extends BaseVOMSESLookupStrategy {
 
-	public static final String DEFAULT_VOMSES_DIR = "/etc/vomses";
-	
-	public DefaultVOMSESLookupStrategy() {
-		super(Arrays.asList(DEFAULT_VOMSES_DIR, 
-				System.getProperty("user.home") + "/.glite/vomses",
-				System.getProperty("user.home") + "/.voms/vomses"
-				));
-	}
+  public static final String DEFAULT_VOMSES_DIR = "/etc/vomses";
+
+  public DefaultVOMSESLookupStrategy() {
+
+    super(Arrays.asList(DEFAULT_VOMSES_DIR, System.getProperty("user.home")
+      + "/.glite/vomses", System.getProperty("user.home") + "/.voms/vomses"));
+  }
 }
